@@ -14,11 +14,11 @@ Device::USB::PCSensor::HidTEMPer::NTC - The HidTEMPerNTC thermometer
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head1 SYNOPSIS
 
@@ -51,6 +51,9 @@ sub init
     # Add sensor references to this instance
     $self->{sensor}->{internal} = Device::USB::PCSensor::HidTEMPer::NTC::Internal->new( $self );
     $self->{sensor}->{external} = Device::USB::PCSensor::HidTEMPer::NTC::External->new( $self );
+
+    # Set configuration
+    $self->_write(0x43);
     
     # Rebless
     bless $self, 'Device::USB::PCSensor::HidTEMPer::NTC';
@@ -91,11 +94,11 @@ Magnus Sulland < msulland@cpan.org >
 
 =head1 ACKNOWLEDGEMENTS
 
-None
+Thanks to Jeremy G for the fix on initializing the device configuration.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2010 Magnus Sulland
+Copyright (c) 2010-2011 Magnus Sulland
 
 This program is free software; you can redistribute it and/or modify it 
 under the same terms as Perl itself.
